==> kubernetes-model-4.1.0-sources.jar: annotations/io/fabric8/openshift/api/model/OAuthAuthorizeTokenFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class OAuthAuthorizeTokenFluentImpl<A extends OAuthAuthorizeTokenFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements OAuthAuthorizeTokenFluent<A>{

    private String apiVersion;
    private String clientName;
    private String codeChallenge;
    private String codeChallengeMethod;
    private Long expiresIn;
    private String kind;
    private ObjectMetaBuilder metadata;
    private String redirectURI;
    private List<String> scopes;
    private String state;
    private String userName;
    private String userUID;

    public OAuthAuthorizeTokenFluentImpl(){
    }
    public OAuthAuthorizeTokenFluentImpl(OAuthAuthorizeToken instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withClientName(instance.getClientName()); 
            this.withCodeChallenge(instance.getCodeChallenge()); 
            this.withCodeChallengeMethod(instance.getCodeChallengeMethod()); 
            this.withExpiresIn(instance.getExpiresIn()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withRedirectURI(instance.getRedirectURI()); 
            this.withScopes(instance.getScopes()); 
            this.withState(instance.getState()); 
            this.withUserName(instance.getUserName()); 
            this.withUserUID(instance.getUserUID()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getClientName(){
            return this.clientName;
    }

    public A withClientName(String clientName){
            this.clientName=clientName; return (A) this;
    }

    public Boolean hasClientName(){
            return this.clientName != null;
    }

    public String getCodeChallenge(){
            return this.codeChallenge;
    }

    public A withCodeChallenge(String codeChallenge){
            this.codeChallenge=codeChallenge; return (A) this;
    }

    public Boolean hasCodeChallenge(){
            return this.codeChallenge != null;
    }

    public String getCodeChallengeMethod(){
            return this.codeChallengeMethod;
    }

    public A withCodeChallengeMethod(String codeChallengeMethod){
            this.codeChallengeMethod=codeChallengeMethod; return (A) this;
    }

    public Boolean hasCodeChallengeMethod(){
            return this.codeChallengeMethod != null;
    }

    public Long getExpiresIn(){
            return this.expiresIn;
    }

    public A withExpiresIn(Long expiresIn){
            this.expiresIn=expiresIn; return (A) this;
    }

    public Boolean hasExpiresIn(){
            return this.expiresIn != null;
    }

    public A withNewExpiresIn(String arg1){
            return (A)withExpiresIn(new Long(arg1));
    }

    public A withNewExpiresIn(long arg1){
            return (A)withExpiresIn(new Long(arg1));
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public String getRedirectURI(){
            return this.redirectURI;
    }

    public A withRedirectURI(String redirectURI){
            this.redirectURI=redirectURI; return (A) this;
    }

    public Boolean hasRedirectURI(){
            return this.redirectURI != null;
    }

    public A addToScopes(int index,String item){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            this.scopes.add(index, item);
            return (A)this;
    }

    public A setToScopes(int index,String item){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            this.scopes.set(index, item); return (A)this;
    }

    public A addToScopes(String... items){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            for (String item : items) {this.scopes.add(item);} return (A)this;
    }

    public A addAllToScopes(Collection<String> items){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            for (String item : items) {this.scopes.add(item);} return (A)this;
    }

    public A removeFromScopes(String... items){
            for (String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
    }

    public A removeAllFromScopes(Collection<String> items){
            for (String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
    }

    public List<String> getScopes(){
            return this.scopes;
    }

    public String getScope(int index){
            return this.scopes.get(index);
    }

    public String getFirstScope(){
            return this.scopes.get(0);
    }

    public String getLastScope(){
            return this.scopes.get(scopes.size() - 1);
    }

    public String getMatchingScope(io.fabric8.kubernetes.api.builder.Predicate<String> predicate){
            for (String item: scopes) { if(predicate.apply(item)){return item;} } return null;
    }

    public A withScopes(List<String> scopes){
            if (this.scopes != null) { _visitables.removeAll(this.scopes);}
            if (scopes != null) {this.scopes = new ArrayList<String>(); for (String item : scopes){this.addToScopes(item);}} else { this.scopes = new ArrayList<String>();} return (A) this;
    }

    public A withScopes(String... scopes){
            if (this.scopes != null) {this.scopes.clear();}
            if (scopes != null) {for (String item :scopes){ this.addToScopes(item);}} return (A) this;
    }

    public Boolean hasScopes(){
            return scopes != null && !scopes.isEmpty();
    }

    public String getState(){
            return this.state;
    }

    public A withState(String state){
            this.state=state; return (A) this;
    }

    public Boolean hasState(){
            return this.state != null;
    }

    public String getUserName(){
            return this.userName;
    }

    public A withUserName(String userName){
            this.userName=userName; return (A) this;
    }

    public Boolean hasUserName(){
            return this.userName != null;
    }

    public String getUserUID(){
            return this.userUID;
    }

    public A withUserUID(String userUID){
            this.userUID=userUID; return (A) this;
    }

    public Boolean hasUserUID(){
            return this.userUID != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            OAuthAuthorizeTokenFluentImpl that = (OAuthAuthorizeTokenFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (clientName != null ? !clientName.equals(that.clientName) :that.clientName != null) return false;
            if (codeChallenge != null ? !codeChallenge.equals(that.codeChallenge) :that.codeChallenge != null) return false;
            if (codeChallengeMethod != null ? !codeChallengeMethod.equals(that.codeChallengeMethod) :that.codeChallengeMethod != null) return false;
            if (expiresIn != null ? !expiresIn.equals(that.expiresIn) :that.expiresIn != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (redirectURI != null ? !redirectURI.equals(that.redirectURI) :that.redirectURI != null) return false;
            if (scopes != null ? !scopes.equals(that.scopes) :that.scopes != null) return false;
            if (state != null ? !state.equals(that.state) :that.state != null) return false;
            if (userName != null ? !userName.equals(that.userName) :that.userName != null) return false;
            if (userUID != null ? !userUID.equals(that.userUID) :that.userUID != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OAuthAuthorizeTokenFluent.MetadataNested<N>> implements OAuthAuthorizeTokenFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) OAuthAuthorizeTokenFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}


}

==> kubernetes-model-4.6.2-sources.jar: annotations/io/fabric8/openshift/api/model/OAuthAuthorizeTokenFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class OAuthAuthorizeTokenFluentImpl<A extends OAuthAuthorizeTokenFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements OAuthAuthorizeTokenFluent<A>{

    private String apiVersion;
    private String clientName;
    private String codeChallenge;
    private String codeChallengeMethod;
    private Long expiresIn;
    private String kind;
    private ObjectMetaBuilder metadata;
    private String redirectURI;
    private List<String> scopes;
    private String state;
    private String userName;
    private String userUID;

    public OAuthAuthorizeTokenFluentImpl(){
    }
    public OAuthAuthorizeTokenFluentImpl(OAuthAuthorizeToken instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withClientName(instance.getClientName()); 
            this.withCodeChallenge(instance.getCodeChallenge()); 
            this.withCodeChallengeMethod(instance.getCodeChallengeMethod()); 
            this.withExpiresIn(instance.getExpiresIn()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.withRedirectURI(instance.getRedirectURI()); 
            this.withScopes(instance.getScopes()); 
            this.withState(instance.getState()); 
            this.withUserName(instance.getUserName()); 
            this.withUserUID(instance.getUserUID()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1){
            return (A)withApiVersion(new String(arg1));
    }

    public String getClientName(){
            return this.clientName;
    }

    public A withClientName(String clientName){
            this.clientName=clientName; return (A) this;
    }

    public Boolean hasClientName(){
            return this.clientName != null;
    }

    public A withNewClientName(String arg1){
            return (A)withClientName(new String(arg1));
    }

    public A withNewClientName(StringBuilder arg1){
            return (A)withClientName(new String(arg1));
    }

    public A withNewClientName(StringBuffer arg1){
            return (A)withClientName(new String(arg1));
    }

    public String getCodeChallenge(){
            return this.codeChallenge;
    }

    public A withCodeChallenge(String codeChallenge){
            this.codeChallenge=codeChallenge; return (A) this;
    }

    public Boolean hasCodeChallenge(){
            return this.codeChallenge != null;
    }

    public A withNewCodeChallenge(String arg1){
            return (A)withCodeChallenge(new String(arg1));
    }

    public A withNewCodeChallenge(StringBuilder arg1){
            return (A)withCodeChallenge(new String(arg1));
    }

    public A withNewCodeChallenge(StringBuffer arg1){
            return (A)withCodeChallenge(new String(arg1));
    }

    public String getCodeChallengeMethod(){
            return this.codeChallengeMethod;
    }

    public A withCodeChallengeMethod(String codeChallengeMethod){
            this.codeChallengeMethod=codeChallengeMethod; return (A) this;
    }

    public Boolean hasCodeChallengeMethod(){
            return this.codeChallengeMethod != null;
    }

    public A withNewCodeChallengeMethod(String arg1){
            return (A)withCodeChallengeMethod(new String(arg1));
    }

    public A withNewCodeChallengeMethod(StringBuilder arg1){
            return (A)withCodeChallengeMethod(new String(arg1));
    }

    public A withNewCodeChallengeMethod(StringBuffer arg1){
            return (A)withCodeChallengeMethod(new String(arg1));
    }

    public Long getExpiresIn(){
            return this.expiresIn;
    }

    public A withExpiresIn(Long expiresIn){
            this.expiresIn=expiresIn; return (A) this;
    }

    public Boolean hasExpiresIn(){
            return this.expiresIn != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public A withNewKind(String arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1){
            return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1){
            return (A)withKind(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.get("metadata").remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public OAuthAuthorizeTokenFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    public String getRedirectURI(){
            return this.redirectURI;
    }

    public A withRedirectURI(String redirectURI){
            this.redirectURI=redirectURI; return (A) this;
    }

    public Boolean hasRedirectURI(){
            return this.redirectURI != null;
    }

    public A withNewRedirectURI(String arg1){
            return (A)withRedirectURI(new String(arg1));
    }

    public A withNewRedirectURI(StringBuilder arg1){
            return (A)withRedirectURI(new String(arg1));
    }

    public A withNewRedirectURI(StringBuffer arg1){
            return (A)withRedirectURI(new String(arg1));
    }

    public A addToScopes(int index,String item){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            this.scopes.add(index, item);
            return (A)this;
    }

    public A setToScopes(int index,String item){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            this.scopes.set(index, item); return (A)this;
    }

    public A addToScopes(String... items){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            for (String item : items) {this.scopes.add(item);} return (A)this;
    }

    public A addAllToScopes(Collection<String> items){
            if (this.scopes == null) {this.scopes = new ArrayList<String>();}
            for (String item : items) {this.scopes.add(item);} return (A)this;
    }

    public A removeFromScopes(String... items){
            for (String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
    }

    public A removeAllFromScopes(Collection<String> items){
            for (String item : items) {if (this.scopes!= null){ this.scopes.remove(item);}} return (A)this;
    }

    public List<String> getScopes(){
            return this.scopes;
    }

    public String getScope(int index){
            return this.scopes.get(index);
    }

    public String getFirstScope(){
            return this.scopes.get(0);
    }

    public String getLastScope(){
            return this.scopes.get(scopes.size() - 1);
    }

    public String getMatchingScope(io.fabric8.kubernetes.api.builder.Predicate<String> predicate){
            for (String item: scopes) { if(predicate.apply(item)){return item;} } return null;
    }

    public Boolean hasMatchingScope(io.fabric8.kubernetes.api.builder.Predicate<String> predicate){
            for (String item: scopes) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withScopes(List<String> scopes){
            if (this.scopes != null) { _visitables.get("scopes").removeAll(this.scopes);}
            if (scopes != null) {this.scopes = new ArrayList<String>(); for (String item : scopes){this.addToScopes(item);}} else { this.scopes = new ArrayList<String>();} return (A) this;
    }

    public A withScopes(String... scopes){
            if (this.scopes != null) {this.scopes.clear();}
            if (scopes != null) {for (String item :scopes){ this.addToScopes(item);}} return (A) this;
    }

    public Boolean hasScopes(){
            return scopes != null && !scopes.isEmpty();
    }

    public A addNewScope(String arg1){
            return (A)addToScopes(new String(arg1));
    }

    public A addNewScope(StringBuilder arg1){
            return (A)addToScopes(new String(arg1));
    }

    public A addNewScope(StringBuffer arg1){
            return (A)addToScopes(new String(arg1));
    }

    public String getState(){
            return this.state;
    }

    public A withState(String state){
            this.state=state; return (A) this;
    }

    public Boolean hasState(){
            return this.state != null;
    }

    public A withNewState(String arg1){
            return (A)withState(new String(arg1));
    }

    public A withNewState(StringBuilder arg1){
            return (A)withState(new String(arg1));
    }

    public A withNewState(StringBuffer arg1){
            return (A)withState(new String(arg1));
    }

    public String getUserName(){
            return this.userName;
    }

    public A withUserName(String userName){
            this.userName=userName; return (A) this;
    }

    public Boolean hasUserName(){
            return this.userName != null;
    }

    public A withNewUserName(String arg1){
            return (A)withUserName(new String(arg1));
    }

    public A withNewUserName(StringBuilder arg1){
            return (A)withUserName(new String(arg1));
    }

    public A withNewUserName(StringBuffer arg1){
            return (A)withUserName(new String(arg1));
    }

    public String getUserUID(){
            return this.userUID;
    }

    public A withUserUID(String userUID){
            this.userUID=userUID; return (A) this;
    }

    public Boolean hasUserUID(){
            return this.userUID != null;
    }

    public A withNewUserUID(String arg1){
            return (A)withUserUID(new String(arg1));
    }

    public A withNewUserUID(StringBuilder arg1){
            return (A)withUserUID(new String(arg1));
    }

    public A withNewUserUID(StringBuffer arg1){
            return (A)withUserUID(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            OAuthAuthorizeTokenFluentImpl that = (OAuthAuthorizeTokenFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (clientName != null ? !clientName.equals(that.clientName) :that.clientName != null) return false;
            if (codeChallenge != null ? !codeChallenge.equals(that.codeChallenge) :that.codeChallenge != null) return false;
            if (codeChallengeMethod != null ? !codeChallengeMethod.equals(that.codeChallengeMethod) :that.codeChallengeMethod != null) return false;
            if (expiresIn != null ? !expiresIn.equals(that.expiresIn) :that.expiresIn != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (redirectURI != null ? !redirectURI.equals(that.redirectURI) :that.redirectURI != null) return false;
            if (scopes != null ? !scopes.equals(that.scopes) :that.scopes != null) return false;
            if (state != null ? !state.equals(that.state) :that.state != null) return false;
            if (userName != null ? !userName.equals(that.userName) :that.userName != null) return false;
            if (userUID != null ? !userUID.equals(that.userUID) :that.userUID != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<OAuthAuthorizeTokenFluent.MetadataNested<N>> implements OAuthAuthorizeTokenFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) OAuthAuthorizeTokenFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}


}
